ProjectHeartbeatDuration class

Mixed-in types
Annotations
  • @freezed

Constructors

ProjectHeartbeatDuration({required String branch, required String language, required String project, required String type, required num time, required num duration, String? entity})
const
factory
ProjectHeartbeatDuration.fromJson(Map<String, dynamic> json)
factory

Properties

branch String
no setterinherited
copyWith → $ProjectHeartbeatDurationCopyWith<ProjectHeartbeatDuration>
no setterinherited
duration num
no setterinherited
entity String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
language String
no setterinherited
project String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time num
no setterinherited
type String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited